/*         1234567890 1234567890 1234567890 1234567890 */
/* --------------------------------------------------- */
/*
          - COMMENT -
     This set of code takes the input file created with
mk-lgt2001.sas which is a person-month file, adds some
mother, father, and spouse characteristics onto it, and
generates a person-level file with variables that can be
arrayed from 1 to 36 for each person.  

        - END COMMENT -
*/
/* --------------------------------------------------- */

options nocenter nodate nonumber source symbolgen compress=yes;

/* -------------------- Libnames  -------------------- */

libname savedat '/home/field005/psidsipp/sipp01/data';

proc contents data=savedat.l01pu varnum;
run;


/* --------------------------------------------------- */
/*
          - COMMENT -
    This short block makes a file with all the people
in the 2001 panel, no matter what wave they entered. It
has no other variables on it, but will be used later as
the first file which the monthly data will be matched on
to inside the macro. After each monthly file is created,
they are sequentially added to the base, creating a
person level file from the person-month level public 
use file.  
        - END COMMENT -
*/
/* --------------------------------------------------- */
data work.person 
         (index=(perid)
           keep=   perid
         );
 set savedat.l01pu;
perid=trim(ssuid)||trim(eentaid)||trim(lgtkey);
run;

proc sort force data=work.person;
  by perid;
run;

data savedat.perid (index=(perid));
 set work.person;
by perid;
if last.perid then output;
run;

proc contents data=savedat.perid varnum;
run;

/* --------------------------------------------------- */
/*
          - COMMENT -
     The next set of merges acts on the longitudinal 
person-month file to link parents info onto kids (all
ages), spouses info together, and guardians onto kids 
for each month.  These will then be converted to 
monthly variables and transformed to person level with
the rest of the wave and monthly variables.
        - END COMMENT -
*/
/* --------------------------------------------------- */



data work.withrents (index=(momid));
set savedat.l01pu;
   momid  = trim(ssuid)||trim(epnmom)||trim(lgtmon);
   dadid  = trim(ssuid)||trim(epndad)||trim(lgtmon);
   grdid  = trim(ssuid)||trim(epnguard)||trim(lgtmon);
   spsid  = trim(ssuid)||trim(epnspous)||trim(lgtmon);
   pnumid = trim(ssuid)||trim(epppnum)||trim(lgtmon);
run;

data moms
  (index=(momid)
   keep=
        mssuid      mepppnum    mlgtmon     mlgtkey
        mperid      mrace       morigin     meentaid
        mebmnth     mtbyear     momid
        meppintvw   mrenroll    mrenrlma    meenlevel
        meeducate   medisabl    mersnowrk   meptwrk
        mepnspous   mepnmom     metypmom    mepndad
        metypdad    mtage       merrp       mems
        mtpearn     mtptotinc   mtpprpinc   mtptrninc
        mtpothinc   mtppndist   mtplumpsm   mrmesr
        mrwkesr1    mrwkesr2    mrwkesr3    mrwkesr4
        mrwkesr5    mrmwkwjb    mrmwksab    mrmwklkg
        mrmhrswk    mrwksperm
  );
set savedat.l01pu
  (keep=
        ssuid       epppnum     lgtmon      lgtkey
        erace       eorigin      eentaid
        ebmnth      tbyear
        eppintvw    renroll     renrlma     eenlevel
        eeducate    edisabl     ersnowrk    eptwrk
        epnspous    epnmom      etypmom     epndad
        etypdad     tage        errp        ems
        tpearn      tptotinc    tpprpinc    tptrninc
        tpothinc    tppndist    tplumpsm    rmesr
        rwkesr1     rwkesr2     rwkesr3     rwkesr4
        rwkesr5     rmwkwjb     rmwksab     rmwklkg
        rmhrswk     rwksperm
   );

momid = trim(ssuid)||trim(epppnum)||trim(lgtmon);
mperid = trim(ssuid)||trim(eentaid)||trim(lgtkey);

        mssuid   =ssuid;
        mepppnum =epppnum;
        mlgtmon  =lgtmon;
        mlgtkey  =lgtkey;
        mrace    =erace;
        morigin  =eorigin;
        meentaid =eentaid;
        mebmnth  =ebmnth;
        mtbyear  =tbyear;
        meppintvw=eppintvw;
        mrenroll =renroll;
        mrenrlma =renrlma;
        meenlevel=eenlevel;
        meeducate=eeducate;
        medisabl =edisabl;
        mersnowrk=ersnowrk;
        meptwrk  =eptwrk;
        mepnspous=epnspous;
        mepnmom  =epnmom;
        metypmom =etypmom;
        mepndad  =epndad;
        metypdad =etypdad;
        mtage    =tage;
        merrp    =errp;
        mems     =ems;
        mtpearn  =tpearn;
        mtptotinc=tptotinc;
        mtpprpinc=tpprpinc;
        mtptrninc=tptrninc;
        mtpothinc=tpothinc;
        mtppndist=tppndist;
        mtplumpsm=tplumpsm;
        mrmesr   =rmesr;
        mrwkesr1 =rwkesr1;
        mrwkesr2 =rwkesr2;
        mrwkesr3 =rwkesr3;
        mrwkesr4 =rwkesr4;
        mrwkesr5 =rwkesr5;
        mrmwkwjb =rmwkwjb;
        mrmwksab =rmwksab;
        mrmwklkg =rmwklkg;
        mrmhrswk =rmhrswk;
        mrwksperm=rwksperm;

run;

data work.withrents (index=(dadid));
merge work.withrents (in=inmoms) work.moms (in=moms);
 by momid;
 if inmoms;
run;

data dads
  (index=(dadid)
   keep=
        dssuid      depppnum    dlgtmon     dlgtkey
        dperid      drace       dorigin     deentaid
        debmnth     dtbyear     dadid
        deppintvw   drenroll    drenrlma    deenlevel
        deeducate   dedisabl    dersnowrk   deptwrk
        depnspous   depnmom     detypmom    depndad
        detypdad    dtage       derrp       dems
        dtpearn     dtptotinc   dtpprpinc   dtptrninc
        dtpothinc   dtppndist   dtplumpsm   drmesr
        drwkesr1    drwkesr2    drwkesr3    drwkesr4
        drwkesr5    drmwkwjb    drmwksab    drmwklkg
        drmhrswk    drwksperm
  );
set savedat.l01pu
  (keep=
        ssuid       epppnum     lgtmon      lgtkey
        erace       eorigin      eentaid
        ebmnth      tbyear
        eppintvw    renroll     renrlma     eenlevel
        eeducate    edisabl     ersnowrk    eptwrk
        epnspous    epnmom      etypmom     epndad
        etypdad     tage        errp        ems
        tpearn      tptotinc    tpprpinc    tptrninc
        tpothinc    tppndist    tplumpsm    rmesr
        rwkesr1     rwkesr2     rwkesr3     rwkesr4
        rwkesr5     rmwkwjb     rmwksab     rmwklkg
        rmhrswk     rwksperm
   );

dadid = trim(ssuid)||trim(epppnum)||trim(lgtmon);
dperid = trim(ssuid)||trim(eentaid)||trim(lgtkey);

        dssuid   =ssuid;
        depppnum =epppnum;
        dlgtmon  =lgtmon;
        dlgtkey  =lgtkey;
        drace    =erace;
        dorigin  =eorigin;
        deentaid =eentaid;
        debmnth  =ebmnth;
        dtbyear  =tbyear;
        deppintvw=eppintvw;
        drenroll =renroll;
        drenrlma =renrlma;
        deenlevel=eenlevel;
        deeducate=eeducate;
        dedisabl =edisabl;
        dersnowrk=ersnowrk;
        deptwrk  =eptwrk;
        depnspous=epnspous;
        depnmom  =epnmom;
        detypmom =etypmom;
        depndad  =epndad;
        detypdad =etypdad;
        dtage    =tage;
        derrp    =errp;
        dems     =ems;
        dtpearn  =tpearn;
        dtptotinc=tptotinc;
        dtpprpinc=tpprpinc;
        dtptrninc=tptrninc;
        dtpothinc=tpothinc;
        dtppndist=tppndist;
        dtplumpsm=tplumpsm;
        drmesr   =rmesr;
        drwkesr1 =rwkesr1;
        drwkesr2 =rwkesr2;
        drwkesr3 =rwkesr3;
        drwkesr4 =rwkesr4;
        drwkesr5 =rwkesr5;
        drmwkwjb =rmwkwjb;
        drmwksab =rmwksab;
        drmwklkg =rmwklkg;
        drmhrswk =rmhrswk;
        drwksperm=rwksperm;

run;

data work.withrents (index=(grdid));
merge work.withrents (in=indads) work.dads (in=dads);
 by dadid;
 if indads;
run;

data grds
  (index=(grdid)
   keep=
        gssuid      gepppnum    glgtmon     glgtkey
        gperid      grace       gorigin     geentaid
        gebmnth     gtbyear     grdid
        geppintvw   grenroll    grenrlma    geenlevel
        geeducate   gedisabl    gersnowrk   geptwrk
        gepnspous   gepnmom     getypmom    gepndad
        getypdad    gtage       gerrp       gems
        gtpearn     gtptotinc   gtpprpinc   gtptrninc
        gtpothinc   gtppndist   gtplumpsm   grmesr
        grwkesr1    grwkesr2    grwkesr3    grwkesr4
        grwkesr5    grmwkwjb    grmwksab    grmwklkg
        grmhrswk    grwksperm
  );
set savedat.l01pu
  (keep=
        ssuid       epppnum     lgtmon      lgtkey
        erace       eorigin      eentaid
        ebmnth      tbyear
        eppintvw    renroll     renrlma     eenlevel
        eeducate    edisabl     ersnowrk    eptwrk
        epnspous    epnmom      etypmom     epndad
        etypdad     tage        errp        ems
        tpearn      tptotinc    tpprpinc    tptrninc
        tpothinc    tppndist    tplumpsm    rmesr
        rwkesr1     rwkesr2     rwkesr3     rwkesr4
        rwkesr5     rmwkwjb     rmwksab     rmwklkg
        rmhrswk     rwksperm
   );

grdid = trim(ssuid)||trim(epppnum)||trim(lgtmon);
gperid = trim(ssuid)||trim(eentaid)||trim(lgtkey);

        gssuid   =ssuid;
        gepppnum =epppnum;
        glgtmon  =lgtmon;
        glgtkey  =lgtkey;
        grace    =erace;
        gorigin  =eorigin;
        geentaid =eentaid;
        gebmnth  =ebmnth;
        gtbyear  =tbyear;
        geppintvw=eppintvw;
        grenroll =renroll;
        grenrlma =renrlma;
        geenlevel=eenlevel;
        geeducate=eeducate;
        gedisabl =edisabl;
        gersnowrk=ersnowrk;
        geptwrk  =eptwrk;
        gepnspous=epnspous;
        gepnmom  =epnmom;
        getypmom =etypmom;
        gepndad  =epndad;
        getypdad =etypdad;
        gtage    =tage;
        gerrp    =errp;
        gems     =ems;
        gtpearn  =tpearn;
        gtptotinc=tptotinc;
        gtpprpinc=tpprpinc;
        gtptrninc=tptrninc;
        gtpothinc=tpothinc;
        gtppndist=tppndist;
        gtplumpsm=tplumpsm;
        grmesr   =rmesr;
        grwkesr1 =rwkesr1;
        grwkesr2 =rwkesr2;
        grwkesr3 =rwkesr3;
        grwkesr4 =rwkesr4;
        grwkesr5 =rwkesr5;
        grmwkwjb =rmwkwjb;
        grmwksab =rmwksab;
        grmwklkg =rmwklkg;
        grmhrswk =rmhrswk;
        grwksperm=rwksperm;

run;

data work.withrents (index=(spsid));
merge work.withrents (in=ingrds) work.grds (in=grds);
 by grdid;
 if ingrds;
run;


data work.spss
  (index=(spsid)
   keep=
        sssuid      sepppnum    slgtmon     slgtkey
        sperid      srace       sorigin     seentaid
        sebmnth     stbyear     spsid
        seppintvw   srenroll    srenrlma    seenlevel
        seeducate   sedisabl    sersnowrk   septwrk
        sepnspous   sepnmom     setypmom    sepndad
        setypdad    stage       serrp       sems
        stpearn     stptotinc   stpprpinc   stptrninc
        stpothinc   stppndist   stplumpsm   srmesr
        srwkesr1    srwkesr2    srwkesr3    srwkesr4
        srwkesr5    srmwkwjb    srmwksab    srmwklkg
        srmhrswk    srwksperm
  );
set savedat.l01pu
  (keep=
        ssuid       epppnum     lgtmon      lgtkey
        erace       eorigin      eentaid
        ebmnth      tbyear
        eppintvw    renroll     renrlma     eenlevel
        eeducate    edisabl     ersnowrk    eptwrk
        epnspous    epnmom      etypmom     epndad
        etypdad     tage        errp        ems
        tpearn      tptotinc    tpprpinc    tptrninc
        tpothinc    tppndist    tplumpsm    rmesr
        rwkesr1     rwkesr2     rwkesr3     rwkesr4
        rwkesr5     rmwkwjb     rmwksab     rmwklkg
        rmhrswk     rwksperm
   );

spsid = trim(ssuid)||trim(epppnum)||trim(lgtmon);
sperid = trim(ssuid)||trim(eentaid)||trim(lgtkey);

        sssuid   =ssuid;
        sepppnum =epppnum;
        slgtmon  =lgtmon;
        slgtkey  =lgtkey;
        sperid   =perid;
        srace    =erace;
        sorigin  =eorigin;
        seentaid =eentaid;
        sebmnth  =ebmnth;
        stbyear  =tbyear;
        seppintvw=eppintvw;
        srenroll =renroll;
        srenrlma =renrlma;
        seenlevel=eenlevel;
        seeducate=eeducate;
        sedisabl =edisabl;
        sersnowrk=ersnowrk;
        septwrk  =eptwrk;
        sepnspous=epnspous;
        sepnmom  =epnmom;
        setypmom =etypmom;
        sepndad  =epndad;
        setypdad =etypdad;
        stage    =tage;
        serrp    =errp;
        sems     =ems;
        stpearn  =tpearn;
        stptotinc=tptotinc;
        stpprpinc=tpprpinc;
        stptrninc=tptrninc;
        stpothinc=tpothinc;
        stppndist=tppndist;
        stplumpsm=tplumpsm;
        srmesr   =rmesr;
        srwkesr1 =rwkesr1;
        srwkesr2 =rwkesr2;
        srwkesr3 =rwkesr3;
        srwkesr4 =rwkesr4;
        srwkesr5 =rwkesr5;
        srmwkwjb =rmwkwjb;
        srmwksab =rmwksab;
        srmwklkg =rmwklkg;
        srmhrswk =rmhrswk;
        srwksperm=rwksperm;

run;

data work.withrents;
merge work.withrents (in=inspss) work.spss (in=spss);
 by spsid;
 if inspss;
run;

/* --------------------------------------------------- */
/*
          - COMMENT -
 Extract person level file from merged person month file
 keeping only person and household level variables. 

 This will be the source of the complete universe of 
 people we will match the monthly and wavely variables
 back together at the person level. 
        - END COMMENT -
*/
/* --------------------------------------------------- */
/* --------------------------------------------------- */

%macro perext;

%do i=1 %to 36;

%if &i=1  %then %let w=1;
%if &i=2  %then %let w=1;
%if &i=3  %then %let w=1;
%if &i=4  %then %let w=1;

%if &i=5  %then %let w=2;
%if &i=6  %then %let w=2;
%if &i=7  %then %let w=2;
%if &i=8  %then %let w=2;

%if &i=9  %then %let w=3;
%if &i=10 %then %let w=3;
%if &i=11 %then %let w=3;
%if &i=12 %then %let w=3;

%if &i=13 %then %let w=4;
%if &i=14 %then %let w=4;
%if &i=15 %then %let w=4;
%if &i=16 %then %let w=4;

%if &i=17 %then %let w=5;
%if &i=18 %then %let w=5;
%if &i=19 %then %let w=5;
%if &i=20 %then %let w=5;

%if &i=21 %then %let w=6;
%if &i=22 %then %let w=6;
%if &i=23 %then %let w=6;
%if &i=24 %then %let w=6;

%if &i=25 %then %let w=7;
%if &i=26 %then %let w=7;
%if &i=27 %then %let w=7;
%if &i=28 %then %let w=7;

%if &i=29 %then %let w=8;
%if &i=30 %then %let w=8;
%if &i=31 %then %let w=8;
%if &i=32 %then %let w=8;

%if &i=33 %then %let w=9;
%if &i=34 %then %let w=9;
%if &i=35 %then %let w=9;
%if &i=36 %then %let w=9;

data work.lgtmo&i 
   (index=(perid)
     keep=      perid      ssuid   srotaton       esex
                erace    eorigin     ebmnth     tbyear
              epppnum    eentaid     lgtkey

              swave&w eoutcome&w eppintvw&w epopstat&w
            etenure&w  epubhse&w  egvtrnt&w  tmthrnt&w
          ewrsect8_&w  eutilyn&w  eegyast&w  eegyamt&w
           ehotlunc&w   rnklun&w efreelun&w efrerdln&w
            ebrkfst&w   rnkbrk&w efreebrk&w efrerdbk&w
            renroll&w  renrlma&w eenlevel&w eeducate&w
           epdjbthn&w ejobsrch&w  ejobtrn&w rjobhelp&w
               emax&w ebuscntr&w ejobcntr&w  edisabl&w
           edisprev&w ersnowrk&w   eptwrk&w  eptresn&w
             elkwrk&w  elayoff&w  rtakjob&w  rnotake&w

             lgtmon&i wpfinwgt&i  srefmon&i  rhcalmn&i
            rhcalyr&i  shhadid&i  gvarstr&i  tfipsst&i
               rhnf&i   rhnfam&i    rhnsf&i ehrefper&i
           ehhnumpp&i   rhtype&i   tmetro&i rhchange&i
              rfid_&i   rfid2_&i   thearn&i
           thprpinc&i thtrninc&i thothinc&i    rhpov&i
             rhnbrf&i   rhcbrf&i   rhmtrf&i thpndist&i
           thlumpsm&i thnoncsh&i thsocsec&i    thssi&i
            thunemp&i   thvets&i   thafdc&i  thfdstp&i
               efnp&i efrefper&i   eftype&i rfchange&i
             efkind&i  rfnkids&i rfownkid&i rfoklt18&i
             tfearn&i tfprpinc&i tftrninc&i tfothinc&i
           tftotinc&i    rfpov&i tfpndist&i tflumpsm&i
           tfsocsec&i    tfssi&i  tfunemp&i   tfvets&i
             tfafdc&i  tffdstp&i     rsid&i    esfnp&i
           esfrfper&i  esftype&i  esfkind&i rschange&i
            tsfearn&i tsprpinc&i tstrninc&i tsothinc&i
           tstotinc&i   rsfpov&i tspndist&i tslumpsm&i
           tssocsec&i    tsssi&i   tsvets&i  tsunemp&i
             tsafdc&i  tsfdstp&i     esfr&i     esft&i
               tage&i     aage&i     errp&i     arrp&i
                ems&i      ams&i epnspous&i apnspous&i
             epnmom&i   apnmom&i   epndad&i   apndad&i
           epnguard&i apnguard&i  etypmom&i  atypmom&i
            etypdad&i  atypdad&i rdesgpnt&i   tpearn&i
           tptotinc&i
           tpprpinc&i tptrninc&i tpothinc&i tppndist&i
           tplumpsm&i    rmesr&i rwkesr1_&i rwkesr2_&i
           rwkesr3_&i rwkesr4_&i rwkesr5_&i  rmwkwjb&i
            rmwksab&i  rmwklkg&i  rmhrswk&i rwksperm&i
             eeno1_&i   eeno2_&i ejbhrs1_&i ejbhrs2_&i
           eclwrk1_&i eclwrk2_&i   ebno1_&i   ebno2_&i
           ehrsbs1_&i ehrsbs2_&i

           mssuid&i    mepppnum&i  mlgtmon&i   mlgtkey&i
           mperid&i    mrace&i     morigin&i   meentaid&i
           mebmnth&i   mtbyear&i   meppintvw&i mrenroll&i
           mrenrlma&i  meenlevel&i meeducate&i medisabl&i
           mersnowrk&i meptwrk&i   mepnspous&i mepnmom&i
           metypmom&i  mepndad&i   metypdad&i  mtage&i
           merrp&i     mems&i      mtpearn&i   mtptotinc&i
           mtpprpinc&i mtptrninc&i mtpothinc&i mtppndist&i
           mtplumpsm&i mrmesr&i    mrwkesr1_&i mrwkesr2_&i
           mrwkesr3_&i mrwkesr4_&i mrwkesr5_&i mrmwkwjb&i
           mrmwksab&i  mrmwklkg&i  mrmhrswk&i  mrwksperm&i

           dssuid&i    depppnum&i  dlgtmon&i   dlgtkey&i
           dperid&i    drace&i     dorigin&i   deentaid&i
           debmnth&i   dtbyear&i   deppintvw&i drenroll&i
           drenrlma&i  deenlevel&i deeducate&i dedisabl&i
           dersnowrk&i deptwrk&i   depnspous&i depnmom&i
           detypmom&i  depndad&i   detypdad&i  dtage&i
           derrp&i     dems&i      dtpearn&i   dtptotinc&i
           dtpprpinc&i dtptrninc&i dtpothinc&i dtppndist&i
           dtplumpsm&i drmesr&i    drwkesr1_&i drwkesr2_&i
           drwkesr3_&i drwkesr4_&i drwkesr5_&i drmwkwjb&i
           drmwksab&i  drmwklkg&i  drmhrswk&i  drwksperm&i

           gssuid&i    gepppnum&i  glgtmon&i   glgtkey&i
           gperid&i    grace&i     gorigin&i   geentaid&i
           gebmnth&i   gtbyear&i   geppintvw&i grenroll&i
           grenrlma&i  geenlevel&i geeducate&i gedisabl&i
           gersnowrk&i geptwrk&i   gepnspous&i gepnmom&i
           getypmom&i  gepndad&i   getypdad&i  gtage&i
           gerrp&i     gems&i      gtpearn&i   gtptotinc&i
           gtpprpinc&i gtptrninc&i gtpothinc&i gtppndist&i
           gtplumpsm&i grmesr&i    grwkesr1_&i grwkesr2_&i
           grwkesr3_&i grwkesr4_&i grwkesr5_&i grmwkwjb&i
           grmwksab&i  grmwklkg&i  grmhrswk&i  grwksperm&i

           sssuid&i    sepppnum&i  slgtmon&i   slgtkey&i
           sperid&i    srace&i     sorigin&i   seentaid&i
           sebmnth&i   stbyear&i   seppintvw&i srenroll&i
           srenrlma&i  seenlevel&i seeducate&i sedisabl&i
           sersnowrk&i septwrk&i   sepnspous&i sepnmom&i
           setypmom&i  sepndad&i   setypdad&i  stage&i
           serrp&i     sems&i      stpearn&i   stptotinc&i
           stpprpinc&i stptrninc&i stpothinc&i stppndist&i
           stplumpsm&i srmesr&i    srwkesr1_&i srwkesr2_&i
           srwkesr3_&i srwkesr4_&i srwkesr5_&i srmwkwjb&i
           srmwksab&i  srmwklkg&i  srmhrswk&i  srwksperm&i

    );
 set work.withrents; 
if lgtmon=&i;

perid=trim(ssuid)||trim(eentaid)||trim(lgtkey);

/*-----------------------------------*/
/*  wavely variables given suffixes  */
/*-----------------------------------*/
      swave&w=swave;
   eoutcome&w=eoutcome;
   eppintvw&w=eppintvw;
   epopstat&w=epopstat;
    etenure&w=etenure;
    epubhse&w=epubhse;
    egvtrnt&w=egvtrnt;
    tmthrnt&w=tmthrnt;
  ewrsect8_&w=ewrsect8;
    eutilyn&w=eutilyn;
    eegyast&w=eegyast;
    eegyamt&w=eegyamt;
   ehotlunc&w=ehotlunc;
     rnklun&w=rnklun;
   efreelun&w=efreelun;
   efrerdln&w=efrerdln;
    ebrkfst&w=ebrkfst;
     rnkbrk&w=rnkbrk;
   efreebrk&w=efreebrk;
   efrerdbk&w=efrerdbk;
    renroll&w=renroll;
    renrlma&w=renrlma;
   eenlevel&w=eenlevel;
   eeducate&w=eeducate;
   epdjbthn&w=epdjbthn;
   ejobsrch&w=ejobsrch;
    ejobtrn&w=ejobtrn;
   rjobhelp&w=rjobhelp;
       emax&w=emax;
   ebuscntr&w=ebuscntr;
   ejobcntr&w=ejobcntr;
    edisabl&w=edisabl;
   edisprev&w=edisprev;
   ersnowrk&w=ersnowrk;
     eptwrk&w=eptwrk;
    eptresn&w=eptresn;
     elkwrk&w=elkwrk;
    elayoff&w=elayoff;
    rtakjob&w=rtakjob;
    rnotake&w=rnotake;

/*-----------------------------------*/
/* monthly variables given suffixes  */
/*-----------------------------------*/
     lgtmon&i=lgtmon;
   wpfinwgt&i=wpfinwgt;
    srefmon&i=srefmon;
    rhcalmn&i=rhcalmn;
    rhcalyr&i=rhcalyr;
    shhadid&i=shhadid;
    gvarstr&i=gvarstr;
    tfipsst&i=tfipsst;
       rhnf&i=rhnf;
     rhnfam&i=rhnfam;
      rhnsf&i=rhnsf;
   ehrefper&i=ehrefper;
   ehhnumpp&i=ehhnumpp;
     rhtype&i=rhtype;
     tmetro&i=tmetro;
   rhchange&i=rhchange;
      rfid_&i=rfid;
     rfid2_&i=rfid2;
     thearn&i=thearn;
   thprpinc&i=thprpinc;
   thtrninc&i=thtrninc;
   thothinc&i=thothinc;
      rhpov&i=rhpov;
     rhnbrf&i=rhnbrf;
     rhcbrf&i=rhcbrf;
     rhmtrf&i=rhmtrf;
   thpndist&i=thpndist;
   thlumpsm&i=thlumpsm;
   thnoncsh&i=thnoncsh;
   thsocsec&i=thsocsec;
      thssi&i=thssi;
    thunemp&i=thunemp;
     thvets&i=thvets;
     thafdc&i=thafdc;
    thfdstp&i=thfdstp;
       efnp&i=efnp;
   efrefper&i=efrefper;
     eftype&i=eftype;
   rfchange&i=rfchange;
     efkind&i=efkind;
    rfnkids&i=rfnkids;
   rfownkid&i=rfownkid;
   rfoklt18&i=rfoklt18;
     tfearn&i=tfearn;
   tfprpinc&i=tfprpinc;
   tftrninc&i=tftrninc;
   tfothinc&i=tfothinc;
   tftotinc&i=tftotinc;
      rfpov&i=rfpov;
   tfpndist&i=tfpndist;
   tflumpsm&i=tflumpsm;
   tfsocsec&i=tfsocsec;
      tfssi&i=tfssi;
    tfunemp&i=tfunemp;
     tfvets&i=tfvets;
     tfafdc&i=tfafdc;
    tffdstp&i=tffdstp;
       rsid&i=rsid;
      esfnp&i=esfnp;
   esfrfper&i=esfrfper;
    esftype&i=esftype;
    esfkind&i=esfkind;
   rschange&i=rschange;
    tsfearn&i=tsfearn;
   tsprpinc&i=tsprpinc;
   tstrninc&i=tstrninc;
   tsothinc&i=tsothinc;
   tstotinc&i=tstotinc;
     rsfpov&i=rsfpov;
   tspndist&i=tspndist;
   tslumpsm&i=tslumpsm;
   tssocsec&i=tssocsec;
      tsssi&i=tsssi;
     tsvets&i=tsvets;
    tsunemp&i=tsunemp;
     tsafdc&i=tsafdc;
    tsfdstp&i=tsfdstp;
       esfr&i=esfr;
       esft&i=esft;
       tage&i=tage;
       aage&i=aage;
       errp&i=errp;
       arrp&i=arrp;
        ems&i=ems;
        ams&i=ams;
   epnspous&i=epnspous;
   apnspous&i=apnspous;
     epnmom&i=epnmom;
     apnmom&i=apnmom;
     epndad&i=epndad;
     apndad&i=apndad;
   epnguard&i=epnguard;
   apnguard&i=apnguard;
    etypmom&i=etypmom;
    atypmom&i=atypmom;
    etypdad&i=etypdad;
    atypdad&i=atypdad;
   rdesgpnt&i=rdesgpnt;
     tpearn&i=tpearn;
   tptotinc&i=tptotinc;
   tpprpinc&i=tpprpinc;
   tptrninc&i=tptrninc;
   tpothinc&i=tpothinc;
   tppndist&i=tppndist;
   tplumpsm&i=tplumpsm;
      rmesr&i=rmesr;
   rwkesr1_&i=rwkesr1;
   rwkesr2_&i=rwkesr2;
   rwkesr3_&i=rwkesr3;
   rwkesr4_&i=rwkesr4;
   rwkesr5_&i=rwkesr5;
    rmwkwjb&i=rmwkwjb;
    rmwksab&i=rmwksab;
    rmwklkg&i=rmwklkg;
    rmhrswk&i=rmhrswk;
   rwksperm&i=rwksperm;
     eeno1_&i=eeno1;
     eeno2_&i=eeno2;
   ejbhrs1_&i=ejbhrs1;
   ejbhrs2_&i=ejbhrs2;
   eclwrk1_&i=eclwrk1;
   eclwrk2_&i=eclwrk2;
     ebno1_&i=ebno1;
     ebno2_&i=ebno2;
   ehrsbs1_&i=ehrsbs1;
   ehrsbs2_&i=ehrsbs2;

/*---------------*/
/*  Mom Vars     */
/*---------------*/

 mssuid&i    =mssuid;
 mepppnum&i  =mepppnum;
 mlgtmon&i   =mlgtmon;
 mlgtkey&i   =mlgtkey;
 mperid&i    =mperid;
 mrace&i     =mrace;
 morigin&i   =morigin;
 meentaid&i  =meentaid;
 mebmnth&i   =mebmnth;
 mtbyear&i   =mtbyear;
 meppintvw&i =meppintvw;
 mrenroll&i  =mrenroll;
 mrenrlma&i  =mrenrlma;
 meenlevel&i =meenlevel;
 meeducate&i =meeducate;
 medisabl&i  =medisabl;
 mersnowrk&i =mersnowrk;
 meptwrk&i   =meptwrk;
 mepnspous&i =mepnspous;
 mepnmom&i   =mepnmom;
 metypmom&i  =metypmom;
 mepndad&i   =mepndad;
 metypdad&i  =metypdad;
 mtage&i     =mtage;
 merrp&i     =merrp;
 mems&i      =mems;
 mtpearn&i   =mtpearn;
 mtptotinc&i =mtptotinc;
 mtpprpinc&i =mtpprpinc;
 mtptrninc&i =mtptrninc;
 mtpothinc&i =mtpothinc;
 mtppndist&i =mtppndist;
 mtplumpsm&i =mtplumpsm;
 mrmesr&i    =mrmesr;
 mrwkesr1_&i =mrwkesr1;
 mrwkesr2_&i =mrwkesr2;
 mrwkesr3_&i =mrwkesr3;
 mrwkesr4_&i =mrwkesr4;
 mrwkesr5_&i =mrwkesr5;
 mrmwkwjb&i  =mrmwkwjb;
 mrmwksab&i  =mrmwksab;
 mrmwklkg&i  =mrmwklkg;
 mrmhrswk&i  =mrmhrswk;
 mrwksperm&i =mrwksperm;

/*---------------*/
/*  Dad Vars     */
/*---------------*/

 dssuid&i    =dssuid;
 depppnum&i  =depppnum;
 dlgtmon&i   =dlgtmon;
 dlgtkey&i   =dlgtkey;
 dperid&i    =dperid;
 drace&i     =drace;
 dorigin&i   =dorigin;
 deentaid&i  =deentaid;
 debmnth&i   =debmnth;
 dtbyear&i   =dtbyear;
 deppintvw&i =deppintvw;
 drenroll&i  =drenroll;
 drenrlma&i  =drenrlma;
 deenlevel&i =deenlevel;
 deeducate&i =deeducate;
 dedisabl&i  =dedisabl;
 dersnowrk&i =dersnowrk;
 deptwrk&i   =deptwrk;
 depnspous&i =depnspous;
 depnmom&i   =depnmom;
 detypmom&i  =detypmom;
 depndad&i   =depndad;
 detypdad&i  =detypdad;
 dtage&i     =dtage;
 derrp&i     =derrp;
 dems&i      =dems;
 dtpearn&i   =dtpearn;
 dtptotinc&i =dtptotinc;
 dtpprpinc&i =dtpprpinc;
 dtptrninc&i =dtptrninc;
 dtpothinc&i =dtpothinc;
 dtppndist&i =dtppndist;
 dtplumpsm&i =dtplumpsm;
 drmesr&i    =drmesr;
 drwkesr1_&i =drwkesr1;
 drwkesr2_&i =drwkesr2;
 drwkesr3_&i =drwkesr3;
 drwkesr4_&i =drwkesr4;
 drwkesr5_&i =drwkesr5;
 drmwkwjb&i  =drmwkwjb;
 drmwksab&i  =drmwksab;
 drmwklkg&i  =drmwklkg;
 drmhrswk&i  =drmhrswk;
 drwksperm&i =drwksperm;

/*---------------*/
/* Guardian Vars */
/*---------------*/

 gssuid&i    =gssuid;
 gepppnum&i  =gepppnum;
 glgtmon&i   =glgtmon;
 glgtkey&i   =glgtkey;
 gperid&i    =gperid;
 grace&i     =grace;
 gorigin&i   =gorigin;
 geentaid&i  =geentaid;
 gebmnth&i   =gebmnth;
 gtbyear&i   =gtbyear;
 geppintvw&i =geppintvw;
 grenroll&i  =grenroll;
 grenrlma&i  =grenrlma;
 geenlevel&i =geenlevel;
 geeducate&i =geeducate;
 gedisabl&i  =gedisabl;
 gersnowrk&i =gersnowrk;
 geptwrk&i   =geptwrk;
 gepnspous&i =gepnspous;
 gepnmom&i   =gepnmom;
 getypmom&i  =getypmom;
 gepndad&i   =gepndad;
 getypdad&i  =getypdad;
 gtage&i     =gtage;
 gerrp&i     =gerrp;
 gems&i      =gems;
 gtpearn&i   =gtpearn;
 gtptotinc&i =gtptotinc;
 gtpprpinc&i =gtpprpinc;
 gtptrninc&i =gtptrninc;
 gtpothinc&i =gtpothinc;
 gtppndist&i =gtppndist;
 gtplumpsm&i =gtplumpsm;
 grmesr&i    =grmesr;
 grwkesr1_&i =grwkesr1;
 grwkesr2_&i =grwkesr2;
 grwkesr3_&i =grwkesr3;
 grwkesr4_&i =grwkesr4;
 grwkesr5_&i =grwkesr5;
 grmwkwjb&i  =grmwkwjb;
 grmwksab&i  =grmwksab;
 grmwklkg&i  =grmwklkg;
 grmhrswk&i  =grmhrswk;
 grwksperm&i =grwksperm;

/*---------------*/
/* Spouse Vars   */
/*---------------*/

 sssuid&i    =sssuid;
 sepppnum&i  =sepppnum;
 slgtmon&i   =slgtmon;
 slgtkey&i   =slgtkey;
 sperid&i    =sperid;
 srace&i     =srace;
 sorigin&i   =sorigin;
 seentaid&i  =seentaid;
 sebmnth&i   =sebmnth;
 stbyear&i   =stbyear;
 seppintvw&i =seppintvw;
 srenroll&i  =srenroll;
 srenrlma&i  =srenrlma;
 seenlevel&i =seenlevel;
 seeducate&i =seeducate;
 sedisabl&i  =sedisabl;
 sersnowrk&i =sersnowrk;
 septwrk&i   =septwrk;
 sepnspous&i =sepnspous;
 sepnmom&i   =sepnmom;
 setypmom&i  =setypmom;
 sepndad&i   =sepndad;
 setypdad&i  =setypdad;
 stage&i     =stage;
 serrp&i     =serrp;
 sems&i      =sems;
 stpearn&i   =stpearn;
 stptotinc&i =stptotinc;
 stpprpinc&i =stpprpinc;
 stptrninc&i =stptrninc;
 stpothinc&i =stpothinc;
 stppndist&i =stppndist;
 stplumpsm&i =stplumpsm;
 srmesr&i    =srmesr;
 srwkesr1_&i =srwkesr1;
 srwkesr2_&i =srwkesr2;
 srwkesr3_&i =srwkesr3;
 srwkesr4_&i =srwkesr4;
 srwkesr5_&i =srwkesr5;
 srmwkwjb&i  =srmwkwjb;
 srmwksab&i  =srmwksab;
 srmwklkg&i  =srmwklkg;
 srmhrswk&i  =srmhrswk;
 srwksperm&i =srwksperm;

/*-----------------*/
/* Variable Labels */
/*-----------------*/

  label       perid='LNGT Person ID';
  label       ssuid='Sample Structure Unit';
  label    srotaton='Rotation Group';
  label        esex='Sex';
  label       erace='Race';
  label     eorigin='Hispanic Origin';
  label      ebmnth='Birth Mo.';
  label      tbyear='Birth Yr.';
  label     epppnum='Person number - unique in ssuid';
  label     eentaid='Entry address id';
  label      lgtkey='LNGT Matching Key with ssuid';
  label     swave&w='Wave - necessary on personmonth file';
  label  eoutcome&w='Household Interview Status';
  label  eppintvw&w='Person Interview Status';
  label  epopstat&w='Adult Status (15+) in 4th mo of wave';
  label   etenure&w='Ownership Status of Housing';
  label   epubhse&w='Public Housing Status';
  label   egvtrnt&w='Gov Rent Assistance';
  label   tmthrnt&w='Amount of mth Rent';
  label ewrsect8_&w='Section 8 Status';
  label   eutilyn&w='Rec Util Assist';
  label   eegyast&w='Rec Energy Assist';
  label   eegyamt&w='Amount of Energy Assist';
  label  ehotlunc&w='Rec Hot Lunch';
  label    rnklun&w='Number of Kids in HH w/ Hot Lunch';
  label  efreelun&w='Qual for Free/Red Lunch';
  label  efrerdln&w='Rec Free or Red Lunch';
  label   ebrkfst&w='Rec School Brkfst';
  label    rnkbrk&w='Number of Kids in HH w/ Sch Brkfst';
  label  efreebrk&w='Qual for Free/Red Brkfst';
  label  efrerdbk&w='Rec Free or Red Brkfst';
  label   renroll&w='Enrollment in Wave';
  label   renrlma&w='Enrolled all 4 mo';
  label  eenlevel&w='Enrollment Level';
  label  eeducate&w='Educational Attainment';
  label  epdjbthn&w='Paid Job in RefPer';
  label  ejobsrch&w='SocSrv Provided Job Assist';
  label   ejobtrn&w='SocSrv Provided Job Trning';
  label  rjobhelp&w='Assist w/ Welfare to Work';
  label      emax&w='Max Number of Weeks in Wave';
  label  ebuscntr&w='Num of Bus in Wave';
  label  ejobcntr&w='Num of Jobs in Wave';
  label   edisabl&w='Had Work Limiting Cndtin';
  label  edisprev&w='Had Work Preventing Cndtin';
  label  ersnowrk&w='Main Rsn Not Wrking';
  label    eptwrk&w='Part-Time Work';
  label   eptresn&w='Main Rsn PT Work';
  label    elkwrk&w='Look for work';
  label   elayoff&w='On Layoff';
  label   rtakjob&w='Could Person Start';
  label   rnotake&w='Rsn Couldnt Start';
  label    lgtmon&i='Longitudinal Month Indicator';
  label  wpfinwgt&i='Person Final Weight';
  label   srefmon&i='Reference Month';
  label   rhcalmn&i='Calendar Month';
  label   rhcalyr&i='Calendar Year';
  label   shhadid&i='Current HHLD Address ID';
  label   gvarstr&i='Variance Stratum Code';
  label   tfipsst&i='FIPS State Code';
  label      rhnf&i='Num of Fams in HH';
  label    rhnfam&i='Num of Fams w/o Rel SFs';
  label     rhnsf&i='Num of Rel SFs';
  label  ehrefper&i='Per Num of HH Ref Per';
  label  ehhnumpp&i='Num of People in HH';
  label    rhtype&i='HH Type';
  label    tmetro&i='Metro Status Recode';
  label  rhchange&i='HH Comp Chng from Last Mo ';
  label     rfid_&i='Fam ID (Primary and Unrel SF)';
  label    rfid2_&i='Fam ID (Related SF)';
  label    thearn&i='Tot HH Earned Income';
  label  thprpinc&i='Tot HH Property Inc';
  label  thtrninc&i='Tot HH Transfer Inc';
  label  thothinc&i='Tot HH Other Inc';
  label     rhpov&i='HH Poverty Threshold';
  label    rhnbrf&i='HH Noncash Benif Rcpt Flg';
  label    rhcbrf&i='HH Cash Benif Rcpt Flg';
  label    rhmtrf&i='HH Means Tested Benif Flg';
  label  thpndist&i='Tot HH Pension Dist';
  label  thlumpsm&i='Tot HH Lump Dist';
  label  thnoncsh&i='Tot HH Noncash Inc';
  label  thsocsec&i='Tot HH SocSec Inc';
  label     thssi&i='Tot HH SSI Inc';
  label   thunemp&i='Tot HH Unemp Inc';
  label    thvets&i='Tot HH Vet Pmts';
  label    thafdc&i='Tot HH AFDC Pmts';
  label   thfdstp&i='Tot HH Food Stp Rcpt';
  label      efnp&i='Num of People in Fam';
  label  efrefper&i='Per Num of Fam Ref Per';
  label    eftype&i='Fam Type';
  label  rfchange&i='Fam Comp Chng from Last Mo';
  label    efkind&i='Fam Kind';
  label   rfnkids&i='Num Kids lt 18 in Fam';
  label  rfownkid&i='Num Own Kids Any Age in Fam';
  label  rfoklt18&i='Num Own Kids lt 18 in Fam';
  label    tfearn&i='Tot Fam Earned Inc';
  label  tfprpinc&i='Tot Fam Property Inc';
  label  tftrninc&i='Tot Fam Transfer Inc';
  label  tfothinc&i='Tot Fam Other Inc';
  label  tftotinc&i='Tot Fam Inc Aggregate';
  label     rfpov&i='Fam Poverty Threshold';
  label  tfpndist&i='Tot Fam Pension Dist';
  label  tflumpsm&i='Tot Fam Lump Dist';
  label  tfsocsec&i='Tot Fam SocSec Inc';
  label     tfssi&i='Tot Fam SSI Inc';
  label   tfunemp&i='Tot Fam Unemp Inc';
  label    tfvets&i='Tot Fam Vet Pmts';
  label    tfafdc&i='Tot Fam AFDC Pmts';
  label   tffdstp&i='Tot Fam Food Stp Rcpt';
  label      rsid&i='Subfamily ID';
  label     esfnp&i='Num of People in SubFam';
  label  esfrfper&i='Per Num of SubFam Ref Per';
  label   esftype&i='SubFam Type';
  label   esfkind&i='SubFam Kind';
  label  rschange&i='SubFam Comp Chng from Last Mo';
  label   tsfearn&i='Tot SubFam Earned Inc';
  label  tsprpinc&i='Tot SubFam Property Inc';
  label  tstrninc&i='Tot SubFam Transfer Inc';
  label  tsothinc&i='Tot SubFam Other Inc';
  label  tstotinc&i='Tot SubFam Inc Aggregate';
  label    rsfpov&i='SubFam Poverty Threshold';
  label  tspndist&i='Tot SubFam Pension Dist';
  label  tslumpsm&i='Tot SubFam Lump Dist';
  label  tssocsec&i='Tot SubFam SocSec Inc';
  label     tsssi&i='Tot SubFam SSI Inc';
  label    tsvets&i='Tot SubFam Vet Pmts';
  label   tsunemp&i='Tot SubFam Unemp Inc';
  label    tsafdc&i='Tot SubFam AFDC Pmts';
  label   tsfdstp&i='Tot SubFam Food Stp Rcpt';
  label      esfr&i='SubFam Relationship Type';
  label      esft&i='SubFam Type';
  label      tage&i='Age';
  label      aage&i='Age Flag';
  label      errp&i='Relationship to HHLDR';
  label      arrp&i='RRP Flag';
  label       ems&i='Marital Status';
  label       ams&i='Marital Stat Flag';
  label  epnspous&i='Per Num of Spouse';
  label  apnspous&i='Spouse Pointer Flag';
  label    epnmom&i='Per Num of Mom';
  label    apnmom&i='Mom Pointer Flag';
  label    epndad&i='Per Num of Dad';
  label    apndad&i='Dad Pointer Flag';
  label  epnguard&i='Per Num of Guardian';
  label  apnguard&i='Guardian Pointer Flag';
  label   etypmom&i='Type of Relationship to Mom';
  label   atypmom&i='Mom Type Flag';
  label   etypdad&i='Type of Relationship to Dad';
  label   atypdad&i='Dad Type Flag';
  label  rdesgpnt&i='Per Num of Designated Parent';
  label    tpearn&i='Tot Per Earned Inc';
  label  tptotinc&i='Tot Inc All Srcs';
  label  tpprpinc&i='Tot Per Property Inc';
  label  tptrninc&i='Tot Per Transfer Inc';
  label  tpothinc&i='Tot Per Other Inc';
  label  tppndist&i='Tot Per Pension Dist';
  label  tplumpsm&i='Tot Per Lump Dist';
  label     rmesr&i='Employment Status Recode';
  label  rwkesr1_&i='Emp Stat Week 1';
  label  rwkesr2_&i='Emp Stat Week 2';
  label  rwkesr3_&i='Emp Stat Week 3';
  label  rwkesr4_&i='Emp Stat Week 4';
  label  rwkesr5_&i='Emp Stat Week 5';
  label   rmwkwjb&i='Weeks w/ Job';
  label   rmwksab&i='Weeks Absent w/o Pay from Job';
  label   rmwklkg&i='Weeks Looking/on Layoff';
  label   rmhrswk&i='Hrs Usually Worked/Week All';
  label  rwksperm&i='Num of Weeks this Mo';
  label    eeno1_&i='Crosswave Employer ID 1';
  label    eeno2_&i='Crosswave Employer ID 2';
  label  ejbhrs1_&i='Hrs Usually Worked/Week Job 1';
  label  ejbhrs2_&i='Hrs Usually Worked/Week Job 2';
  label  eclwrk1_&i='Class of Wrkr Job 1';
  label  eclwrk2_&i='Class of Wrkr Job 2';
  label    ebno1_&i='Crosswave Business ID 1';
  label    ebno2_&i='Crosswave Business ID 2';
  label  ehrsbs1_&i='Hrs Usually Worked/Week Bus 1';
  label  ehrsbs2_&i='Hrs Usually Worked/Week Bus 2';

  label mssuid&i    ='Mom Sample Structure Unit';
  label mepppnum&i  ='Mom Person Number';
  label mlgtmon&i   ='Mom Lgt Mon Key';
  label mlgtkey&i   ='Mom Lgt Person Key';
  label mperid&i    ='Mom Perid Created';
  label mrace&i     ='Mom Race';
  label morigin&i   ='Mom Hispanic Origin';
  label meentaid&i  ='Mom Entry Add Id';
  label mebmnth&i   ='Mom Birth Month';
  label mtbyear&i   ='Mom Birth Year';
  label meppintvw&i ='Mom Interview Status';
  label mrenroll&i  ='Mom Enrollment (wave)';
  label mrenrlma&i  ='Mom Enrollment All Wave';
  label meenlevel&i ='Mom Enrollment Level';
  label meeducate&i ='Mom Educ Attainment';
  label medisabl&i  ='Mom Work Lmt Cndtin';
  label mersnowrk&i ='Mom Main Rsn Not Wrk';
  label meptwrk&i   ='Mom Part-time Wrk';
  label mepnspous&i ='Mom Per Num Her Spouse';
  label mepnmom&i   ='Mom Per Num Her Mom';
  label metypmom&i  ='Mom Type Her Mom';
  label mepndad&i   ='Mom Per Num Her Dad';
  label metypdad&i  ='Mom Type Her Dad';
  label mtage&i     ='Mom Age';
  label merrp&i     ='Mom Relationship HHLDR';
  label mems&i      ='Mom Marital Status';
  label mtpearn&i   ='Mom Work Earnings';
  label mtptotinc&i ='Mom Total Income';
  label mtpprpinc&i ='Mom Prop Income';
  label mtptrninc&i ='Mom Transfer Income';
  label mtpothinc&i ='Mom Other Income';
  label mtppndist&i ='Mom Pension Dist';
  label mtplumpsm&i ='Mom Lump Dist';
  label mrmesr&i    ='Mom Work Status';
  label mrwkesr1_&i ='Mom Work Stat Wk 1';
  label mrwkesr2_&i ='Mom Work Stat Wk 2';
  label mrwkesr3_&i ='Mom Work Stat Wk 3';
  label mrwkesr4_&i ='Mom Work Stat Wk 4';
  label mrwkesr5_&i ='Mom Work Stat Wk 5';
  label mrmwkwjb&i  ='Mom Weeks w/ Job';
  label mrmwksab&i  ='Mom Weeks Abs w/o Pay Job';
  label mrmwklkg&i  ='Mom Weeks Looking/Layoff';
  label mrmhrswk&i  ='Mom Hours Usually Wrkd/Wk';
  label mrwksperm&i ='Mom Weeks This Mo';


  label dssuid&i    ='Dad Sample Structure Unit';
  label depppnum&i  ='Dad Person Number';
  label dlgtmon&i   ='Dad Lgt Mon Key';
  label dlgtkey&i   ='Dad Lgt Person Key';
  label dperid&i    ='Dad Perid Created';
  label drace&i     ='Dad Race';
  label dorigin&i   ='Dad Hispanic Origin';
  label deentaid&i  ='Dad Entry Add Id';
  label debmnth&i   ='Dad Birth Month';
  label dtbyear&i   ='Dad Birth Year';
  label deppintvw&i ='Dad Interview Status';
  label drenroll&i  ='Dad Enrollment (wave)';
  label drenrlma&i  ='Dad Enrollment All Wave';
  label deenlevel&i ='Dad Enrollment Level';
  label deeducate&i ='Dad Educ Attainment';
  label dedisabl&i  ='Dad Work Lmt Cndtin';
  label dersnowrk&i ='Dad Main Rsn Not Wrk';
  label deptwrk&i   ='Dad Part-time Wrk';
  label depnspous&i ='Dad Per Num His Spouse';
  label depnmom&i   ='Dad Per Num His Mom';
  label detypmom&i  ='Dad Type His Mom';
  label depndad&i   ='Dad Per Num His Dad';
  label detypdad&i  ='Dad Type His Dad';
  label dtage&i     ='Dad Age';
  label derrp&i     ='Dad Relationship HHLDR';
  label dems&i      ='Dad Marital Status';
  label dtpearn&i   ='Dad Work Earnings';
  label dtptotinc&i ='Dad Total Income';
  label dtpprpinc&i ='Dad Prop Income';
  label dtptrninc&i ='Dad Transfer Income';
  label dtpothinc&i ='Dad Other Income';
  label dtppndist&i ='Dad Pension Dist';
  label dtplumpsm&i ='Dad Lump Dist';
  label drmesr&i    ='Dad Work Status';
  label drwkesr1_&i ='Dad Work Stat Wk 1';
  label drwkesr2_&i ='Dad Work Stat Wk 2';
  label drwkesr3_&i ='Dad Work Stat Wk 3';
  label drwkesr4_&i ='Dad Work Stat Wk 4';
  label drwkesr5_&i ='Dad Work Stat Wk 5';
  label drmwkwjb&i  ='Dad Weeks w/ Job';
  label drmwksab&i  ='Dad Weeks Abs w/o Pay Job';
  label drmwklkg&i  ='Dad Weeks Looking/Layoff';
  label drmhrswk&i  ='Dad Hours Usually Wrkd/Wk';
  label drwksperm&i ='Dad Weeks This Mo';


  label gssuid&i    ='Grd Sample Structure Unit';
  label gepppnum&i  ='Grd Person Number';
  label glgtmon&i   ='Grd Lgt Mon Key';
  label glgtkey&i   ='Grd Lgt Person Key';
  label gperid&i    ='Grd Perid Created';
  label grace&i     ='Grd Race';
  label gorigin&i   ='Grd Hispanic Origin';
  label geentaid&i  ='Grd Entry Add Id';
  label gebmnth&i   ='Grd Birth Month';
  label gtbyear&i   ='Grd Birth Year';
  label geppintvw&i ='Grd Interview Status';
  label grenroll&i  ='Grd Enrollment (wave)';
  label grenrlma&i  ='Grd Enrollment All Wave';
  label geenlevel&i ='Grd Enrollment Level';
  label geeducate&i ='Grd Educ Attainment';
  label gedisabl&i  ='Grd Work Lmt Cndtin';
  label gersnowrk&i ='Grd Main Rsn Not Wrk';
  label geptwrk&i   ='Grd Part-time Wrk';
  label gepnspous&i ='Grd Per Num Their Spouse';
  label gepnmom&i   ='Grd Per Num Their Mom';
  label getypmom&i  ='Grd Type Their Mom';
  label gepndad&i   ='Grd Per Num Their Dad';
  label getypdad&i  ='Grd Type Their Dad';
  label gtage&i     ='Grd Age';
  label gerrp&i     ='Grd Relationship HHLDR';
  label gems&i      ='Grd Marital Status';
  label gtpearn&i   ='Grd Work Earnings';
  label gtptotinc&i ='Grd Total Income';
  label gtpprpinc&i ='Grd Prop Income';
  label gtptrninc&i ='Grd Transfer Income';
  label gtpothinc&i ='Grd Other Income';
  label gtppndist&i ='Grd Pension Dist';
  label gtplumpsm&i ='Grd Lump Dist';
  label grmesr&i    ='Grd Work Status';
  label grwkesr1_&i ='Grd Work Stat Wk 1';
  label grwkesr2_&i ='Grd Work Stat Wk 2';
  label grwkesr3_&i ='Grd Work Stat Wk 3';
  label grwkesr4_&i ='Grd Work Stat Wk 4';
  label grwkesr5_&i ='Grd Work Stat Wk 5';
  label grmwkwjb&i  ='Grd Weeks w/ Job';
  label grmwksab&i  ='Grd Weeks Abs w/o Pay Job';
  label grmwklkg&i  ='Grd Weeks Looking/Layoff';
  label grmhrswk&i  ='Grd Hours Usually Wrkd/Wk';
  label grwksperm&i ='Grd Weeks This Mo';

  label sssuid&i    ='Sps Sample Structure Unit';
  label sepppnum&i  ='Sps Person Number';
  label slgtmon&i   ='Sps Lgt Mon Key';
  label slgtkey&i   ='Sps Lgt Person Key';
  label sperid&i    ='Sps Perid Created';
  label srace&i     ='Sps Race';
  label sorigin&i   ='Sps Hispanic Origin';
  label seentaid&i  ='Sps Entry Add Id';
  label sebmnth&i   ='Sps Birth Month';
  label stbyear&i   ='Sps Birth Year';
  label seppintvw&i ='Sps Interview Status';
  label srenroll&i  ='Sps Enrollment (wave)';
  label srenrlma&i  ='Sps Enrollment All Wave';
  label seenlevel&i ='Sps Enrollment Level';
  label seeducate&i ='Sps Educ Attainment';
  label sedisabl&i  ='Sps Work Lmt Cndtin';
  label sersnowrk&i ='Sps Main Rsn Not Wrk';
  label septwrk&i   ='Sps Part-time Wrk';
  label sepnspous&i ='Sps Per Num Their Spouse';
  label sepnmom&i   ='Sps Per Num Their Mom';
  label setypmom&i  ='Sps Type Their Mom';
  label sepndad&i   ='Sps Per Num Their Dad';
  label setypdad&i  ='Sps Type Their Dad';
  label stage&i     ='Sps Age';
  label serrp&i     ='Sps Relationship HHLDR';
  label sems&i      ='Sps Marital Status';
  label stpearn&i   ='Sps Work Earnings';
  label stptotinc&i ='Sps Total Income';
  label stpprpinc&i ='Sps Prop Income';
  label stptrninc&i ='Sps Transfer Income';
  label stpothinc&i ='Sps Other Income';
  label stppndist&i ='Sps Pension Dist';
  label stplumpsm&i ='Sps Lump Dist';
  label srmesr&i    ='Sps Work Status';
  label srwkesr1_&i ='Sps Work Stat Wk 1';
  label srwkesr2_&i ='Sps Work Stat Wk 2';
  label srwkesr3_&i ='Sps Work Stat Wk 3';
  label srwkesr4_&i ='Sps Work Stat Wk 4';
  label srwkesr5_&i ='Sps Work Stat Wk 5';
  label srmwkwjb&i  ='Sps Weeks w/ Job';
  label srmwksab&i  ='Sps Weeks Abs w/o Pay Job';
  label srmwklkg&i  ='Sps Weeks Looking/Layoff';
  label srmhrswk&i  ='Sps Hours Usually Wrkd/Wk';
  label srwksperm&i ='Sps Weeks This Mo';

run;


proc contents data=work.lgtmo&i varnum; 
run; 


/* --------------------------------------------------- */
/*
          - COMMENT -

Take the monthly files made by the macro above, and merge
with the unique person number file created at the top.

        - END COMMENT -
*/
/* --------------------------------------------------- */


data savedat.perid (index=(perid));
 merge savedat.perid (in=inper) work.lgtmo&i (in=inmo);
  if inper;
  by perid;
run;

%end;

%mend perext;
%perext
run;


/*  FORMATS   */
/*
PROC FORMAT;
    VALUE AGE_CAT  1 = '0  - 14 YEARS'    2 = '15 - 19 YEARS'
                   3 = '20 - 24 YEARS'    4 = '25 - 29 YEARS'
                   5 = '30 - 34 YEARS'    6 = '35 - 39 YEARS'
                   7 = '40 - 44 YEARS'    8 = '45 - 49 YEARS'
                   9 = '50 - 54 YEARS'    10= '55 - 59 YEARS'
                   11= '60 - 64 YEARS'    12= '65 - 69 YEARS'
                   13= '70 - 74 YEARS'    14= '75 - 79 YEARS'
                   15= '80 YEARS AND UP';
    VALUE AGE_LE   0 = 'AGE 15 AND OVER'
                   1 = 'AGE 14 AND UNDER';
     VALUE FTYPE   1 = 'PRIMARY'
                   2 = 'RELATED SUBFAMILY'
                   3 = 'UNRELATED SUBFAMILY'
                   4 = 'PRIMARY INDIVIDUAL'
                   5 = 'SECONDARY INDIVIDUAL';
     VALUE FKIND   1 = 'HEADED BY HUSBAND/WIFE'
                   2 = 'MALE HEADED'
                   3 = 'FEMALE HEADED';
     VALUE XMONTH  1 = 'JAN'      2 = 'FEB'      3 = 'MAR'
                   4 = 'APR'      5 = 'MAY'      6 = 'JUN'
                   7 = 'JUL'      8 = 'AUG'      9 = 'SEP'
                   10= 'OCT'     11 = 'NOV'     12 = 'DEC';
     VALUE SEX     1 = 'MALE'     2 = 'FEMALE';
     VALUE RACE    1 = 'WHITE'                   2 = 'BLACK'
                   3 = 'AM IND,ALEUT,ESK'        4 = 'API';
     VALUE MARST   1 = 'MARRIED SP PRES'
                   2 = 'MARRIED SP ABS'
                   3 = 'WIDOWED'
                   4 = 'DIVORCED'
                   5 = 'SEPARATED'
                   6 = 'NEV MARRIED';
     VALUE TYPKID  1 = 'BIO OR NAT CHILD'
                   2 = 'STEPCHILD'
                   3 = 'ADOPTED CHILD'
                   4 = 'FOSTER CHILD';
     VALUE SUBFREL 0 = 'NOT IN REL/UNREL SUBFAM'
                   1 = 'REFPER OF REL/UNREL SUBFAM'
                   2 = 'SP OF REFPER OF REL/UNREL SF'
                   3 = 'KID OF RP OF REL/UNREL SF';
     VALUE SUBFTYP 0 = 'PRIMARY FAMILY OR NOT IN SAMP'
                   1 = 'SECONDARY INDIV'
                   2 = 'UNRELATED SUBFAMILY'
                   3 = 'RELATED SUBFAMILY'
                   4 = 'PRIMARY INDIVIDUAL';
     VALUE RRP     1 = 'REF PERSON W/ REL PER IN HH'
                   2 = 'REF PERSON W/0 REL PER IN HH'
                   3 = 'SPOUSE'
                   4 = 'CHILD'
                   5 = 'GRANDCHILD'
                   6 = 'PARENT'
                   7 = 'BROTHER/SISTER'
                   8 = 'OTHER REL OF REF PER'
                   9 = 'FOSTER CHILD'
                   10= 'UNMARRIED PARTNER'
                   11= 'HOUSEMATE/ROOMMATE'
                   12= 'ROOMER/BOARDER'
                   13= 'OTHER NON-RELATIVE OF REF PER';
    value alocate  0 = 'not allocated'
                   1 = 'hot deck allocation'
                   2 = 'cold deck allocation'
                   3 = 'logical imputation';
RUN;
*/

endsas;

/* --------------------------------------------------- */
/*
          - COMMENT -


        - END COMMENT -
*/
/* --------------------------------------------------- */


